from qplay_cli.api_clients.user_api import UserAPIClient
import click
import getpass

@click.group()
def user():
    pass

@user.command()
def signup():
    print("Enter your username:")
    username = input()
    
    print("Enter email address:")
    email = input()
    
    print("Enter your name:")
    name = input()
    
    p = getpass.getpass()
    
    response = User().signup(username, name, email, p)
    print(response['message'])
    
    print("Enter verification code")
    code = input()
    response = User().confirm_signup(username, name, code)
    print(response['message'])
    
    UserAPIClient().signin(username, p)
    
 
@user.command() 
def signin():
    print("Enter your username:")
    username = input()
    
    password = getpass.getpass()
    UserAPIClient().signin(username, password)
    print("Sign in sucessfull")


from qplay_cli.backtest.backtesting import Backtesting
import click

@click.group()
def backtest():
    pass

@backtest.command()
@click.option('--strategy', default=None)
def remote_backtest(strategy):
    if not strategy:
        raise Exception("must provide strategy")
    b = Backtesting()
    b.remote_backtest(strategy)


import click
from qplay_cli.dataset.commands import dataset
from qplay_cli.backtest.commands import backtest
from qplay_cli.user.commands import user
from qplay_cli.machine.commands import machine

@click.group()
def quantplay():
    pass

quantplay.add_command(dataset)
quantplay.add_command(backtest)
quantplay.add_command(user)
quantplay.add_command(machine)
    
if __name__ == '__main__':
    quantplay()


from qplay_cli.api_clients.instance_api import InstanceAPIClient
from qplay_cli.config.qplay_config import QplayConfig
import click

@click.group()
def machine():
    pass

@machine.command()
def launch():
    credentials = QplayConfig.get_credentials()
    access_token = credentials['DEFAULT']['access_token']

    print("Enter lease time in hours")
    lease_time = input()

    response = InstanceAPIClient().launch_machine(access_token, lease_time)
    print(response['message'])


import requests
import json
from retrying import retry
from ec2_metadata import ec2_metadata

class VolumeAPIClient:
    """Api Client of the Volume API
    """
    
    BASE_PROD_URL = "https://3sv4wcd21a.execute-api.ap-south-1.amazonaws.com/prod"
    
    def __init__(self):
        pass
    
    @retry(wait_exponential_multiplier=1000, wait_exponential_max=10000, stop_max_attempt_number=8)
    def get_volume_info(self, volume_id='', device_name=''):
        """Returns volume info (tag, assigned sd_device) for the ebs volume 
        identified either through volume_id or (user_name, device_name)
        
        :param: volume_id: str
        :param: user_name: str, e.g. MLModel
        :param: device_name: str, e.g. xvdf
        :returns: dictionary
        """
        url = VolumeAPIClient.BASE_PROD_URL
        
        if volume_id:
            url += "?volume_id={}".format(volume_id)
        elif device_name:
            url += "?dns_name={}&device_name={}".format(ec2_metadata.public_hostname, device_name)
        else:
            raise Exception("Invalid input. Must provide one among a) volume_id, or b) user_name and device_name")
        
        print("Querying url {}".format(url))
        
        response = requests.get(url)
        resp_json = response.json()
        
        vol_info = {"DatasetType": None}
        
        if resp_json["tags"]:
            vol_info = {a['Key']: a['Value'] for a in resp_json["tags"]}
            
        vol_info["SD_DEVICE"] = resp_json["sd"]
        return vol_info


import requests
import json
from qplay_cli.config.qplay_config import QplayConfig

class UserAPIClient:

    BASE_PROD_URL = 'https://s5y92z0788.execute-api.ap-south-1.amazonaws.com/prod'

    def __init__(self):
        pass

    def signup(self, username, name, email, password):
        x = requests.post(
            UserAPIClient + "/signup",
            data=json.dumps(
                {
                    'username': username,
                    'password': password,
                    "email": email,
                    "name": name

                }))
        response = json.loads(x.text)

        if response['error'] == True:
            print(response['message'])
            quit()

        return response

    def confirm_signup(self, username, password, code):
        x = requests.post(
            UserAPIClient.BASE_PROD_URL + "/confirm_signup",
            data=json.dumps(
                {
                    'username': username,
                    'password': password,
                    "code": code

                }))
        response = json.loads(x.text)

        if response['error'] == True:
            print(response['message'])
            quit()

        return response

    def signin(self, username, password):
        x = requests.post(UserAPIClient.BASE_PROD_URL + "/signin", data=json.dumps({'username': username, 'password': password}))
        access_token = json.loads(x.text)['data']['access_token']
        QplayConfig.save_credentials(access_token)



import requests
import json


class InstanceAPIClient:
    BASE_PROD_URL = "https://h5y8burhuk.execute-api.ap-south-1.amazonaws.com/prod"

    def __init__(self):
        pass

    def launch_machine(self, access_token, lease_time):
        x = requests.post(
            InstanceAPIClient.BASE_PROD_URL + "/launch_instance",
            data=json.dumps(
                {
                    "access_token": str(access_token),
                    "lease_time": str(lease_time)
                }))
        response = json.loads(x.text)

        if response['error'] == True:
            print(response['message'])
            quit()

        return response


from setuptools import setup, find_packages

setup(
    name="qplay-cli",
    version='1.0.6',
    packages=['qplay_cli', 'qplay_cli.api_clients', 'qplay_cli.dataset', 'qplay_cli.backtest', 'qplay_cli.user', 'qplay_cli.config', 'qplay_cli.machine'],
    include_package_data=True,
    install_requires=[
        'Click',
        'requests',
        'retrying',
        'ec2-metadata'
    ],
    entry_points='''
        [console_scripts]
        quantplay=qplay_cli.main:quantplay
    ''',
)